'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.duration = undefined;

var _promise = require('babel-runtime/core-js/promise');

var _promise2 = _interopRequireDefault(_promise);

exports.increaseTime = increaseTime;
exports.increaseTimeTo = increaseTimeTo;

var _latestTime = require('./latest-time');

var _latestTime2 = _interopRequireDefault(_latestTime);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function increaseTime(duration) {
  var id = Date.now();

  return new _promise2.default(function (resolve, reject) {
    web3.currentProvider.sendAsync({
      jsonrpc: '2.0',
      method: 'evm_increaseTime',
      params: [duration],
      id: id
    }, function (err1) {
      var toReturn = void 0;
      if (err1) {
        toReturn = reject(err1);
      } else {
        toReturn = web3.currentProvider.sendAsync({
          jsonrpc: '2.0',
          method: 'evm_mine',
          id: id + 1
        }, function (err2, res) {
          return err2 ? reject(err2) : resolve(res);
        });
      }
      return toReturn;
    });
  });
}

function increaseTimeTo(target) {
  var now = (0, _latestTime2.default)();
  if (target < now) {
    throw Error('Cannot increase current time(' + now + ') to a moment in the past(' + target + ')');
  }
  var diff = target - now;
  return increaseTime(diff);
}

var duration = exports.duration = {
  seconds: function seconds(val) {
    return val;
  },
  minutes: function minutes(val) {
    return val * this.seconds(60);
  },
  hours: function hours(val) {
    return val * this.minutes(60);
  },
  days: function days(val) {
    return val * this.hours(24);
  },
  weeks: function weeks(val) {
    return val * this.days(7);
  },
  years: function years(val) {
    return val * this.days(365);
  }
};